Name:           frescobaldi
Version:        2.0.2
Release:        3%{?dist}
Summary:        Edit LilyPond sheet music with ease!
Group:          Applications/Editors
# hyphenator.py is LGPLv2+
# The rest, including the core of the program, is GPLv2+
License:        GPLv2+ and LGPLv2+
URL:            http://www.frescobaldi.org/
Source0:        https://github.com/downloads/wbsoft/%{name}/%{name}-%{version}.tar.gz
BuildArch:      noarch

BuildRequires:  desktop-file-utils
BuildRequires:  python2-devel
BuildRequires:  gettext
Requires:       alsa-utils
Requires:       lilypond
Requires:       python-poppler-qt4
Requires:       portmidi
Requires:       python-portmidi

%description
Frescobaldi is a LilyPond sheet music editor for KDE4. It aims to be powerful,
yet lightweight and easy to use. It features:

    * Enter LilyPond scores, build and preview them with a mouse-click
    * Point-and-click support: click on notes or error messages to jump to the
      correct position
    * A powerful Score Wizard to quickly setup a musical score
    * Editing tools to:
          o manipulate the rhythm
          o hyphenate lyrics
          o quickly enter or add articulations and other symbols to existing 
            music
          o run the document through convert-ly to update it to a newer 
            LilyPond version
    * Context sensitive auto-complete, helping you to quickly enter LilyPond 
      commands
    * Expansion manager to enter larger snippets of LilyPond input using short
      mnemonics
    * A powerful Rumor plugin, using the Rumor program to quickly enter music
      by playing it on a MIDI keyboard or even your computer keyboard
    * Built-in comprehensive User Guide


%prep
%setup -q
find -name "*.py"  -exec sed -i -e 's|#! python||' {} \;

%build
python ./setup.py build 
cd %{name}_app/po
make

%install
python ./setup.py install --skip-build --prefix=%{buildroot}%{_prefix}


## File lists
# Create the lang file. %%find_lang does not handle .po files
for file in %{buildroot}%{python_sitelib}/%{name}_app/po/*.mo; do
    language=$(basename $file|cut -f 2 -d _|sed 's|\..*||')
    echo language
    echo %%lang\($language\) %{python_sitelib}/%{name}_app/po/$language.mo >> frescobaldi.lang
    done

# desktop file
desktop-file-install                                         \
   --dir=%{buildroot}%{_datadir}/applications                \
   --remove-category=Application                             \
   --add-category=AudioVideo                                 \
   --add-category=X-Notation                                 \
   --delete-original                                         \
   %{name}.desktop

# sane file permissions
find %{buildroot}/%{python_sitelib}/%{name}_app/ -name "*.py*" -exec chmod 644 {} \;
# correct generated shebangs
sed -i -e 's|#!/usr/bin/python||' \
    %{buildroot}/%{python_sitelib}/%{name}_app/language_names/generate.py

%post
update-desktop-database &> /dev/null || :
touch --no-create %{_datadir}/icons/hicolor &>/dev/null || :

%postun
update-desktop-database &> /dev/null || :
if [ $1 -eq 0 ] ; then
    touch --no-create %{_datadir}/icons/hicolor &>/dev/null
    gtk-update-icon-cache %{_datadir}/icons/hicolor &>/dev/null || :
fi

%posttrans
gtk-update-icon-cache %{_datadir}/icons/hicolor &>/dev/null || :

%files -f %{name}.lang
%doc ChangeLog COPYING README* THANKS TODO
%{_bindir}/%{name}
%{python_sitelib}/%{name}_app
# the following is in our lang file
%exclude %{python_sitelib}/%{name}_app/po/*.mo
%{python_sitelib}/%{name}-%{version}-py2.7.egg-info
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/scalable/apps/%{name}.svg

%changelog
* Wed Jan 17 2012 Brendan Jones <brendan.jones.it@gmail.com> - 2.0.2-3
- Exclude only .mo files, not the whole directory

* Wed Jan 17 2012 Brendan Jones <brendan.jones.it@gmail.com> - 2.0.2-2
- Removed rumor/timidity++ requires added portmidi and bindings

* Mon Jan 16 2012 Brendan Jones <brendan.jones.it@gmail.com> - 2.0.2-1
- New upstream version

* Fri Jan 13 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.2.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.2.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Thu Dec 30 2010 Orcan Ogetbil <oget [DOT] fedora [AT] gmail [DOT] com> - 1.2.0-1
- New upstream version
- Drop upstreamed py2.7 patch

* Thu Aug 19 2010 Orcan Ogetbil <oget [DOT] fedora [AT] gmail [DOT] com> - 1.0.3-1
- New upstream version (for KDE 4.5)
- Drop BR: gettext ImageMagick lilypond that are no longer required

* Tue Jul 27 2010 Orcan Ogetbil <oget [DOT] fedora [AT] gmail [DOT] com> - 1.0.2-3
- Enable build for python-2.7

* Tue Jul 27 2010 David Malcolm <dmalcolm@redhat.com> - 1.0.2-2
- Rebuilt for https://fedoraproject.org/wiki/Features/Python_2.7/MassRebuild

* Sat Feb 20 2010 Orcan Ogetbil <oget [DOT] fedora [AT] gmail [DOT] com> - 1.0.2-1
- New upstream version (for KDE 4.4)

* Sat Jan 30 2010 Orcan Ogetbil <oget [DOT] fedora [AT] gmail [DOT] com> - 1.0.1-1
- New upstream version

* Wed Nov 18 2009 Orcan Ogetbil <oget [DOT] fedora [AT] gmail [DOT] com> - 0.7.16-1
- New upstream version

* Thu Sep 17 2009 Orcan Ogetbil <oget [DOT] fedora [AT] gmail [DOT] com> - 0.7.14-1
- New upstream version

* Mon Aug 10 2009 Orcan Ogetbil <oget [DOT] fedora [AT] gmail [DOT] com> - 0.7.13-1
- New upstream version
- No need to rebuild .mo and .png files per new guidelines

* Wed Aug 05 2009 Orcan Ogetbil <oget [DOT] fedora [AT] gmail [DOT] com> - 0.7.12-3
- Update the .desktop file

* Fri Jul 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.7.12-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Sun Jul 05 2009 Orcan Ogetbil <oget [DOT] fedora [AT] gmail [DOT] com> - 0.7.12-1
- New upstream version

* Mon Jun 15 2009 Orcan Ogetbil <oget [DOT] fedora [AT] gmail [DOT] com> - 0.7.11-1
- New upstream version

* Tue Jun 09 2009 Orcan Ogetbil <oget [DOT] fedora [AT] gmail [DOT] com> - 0.7.10-1
- New upstream version
- Decompress the icon. RHBZ #491016 is being ignored.

* Sat May 23 2009 Orcan Ogetbil <oget [DOT] fedora [AT] gmail [DOT] com> - 0.7.9-1
- New upstream version

* Tue Mar 24 2009 Orcan Ogetbil <oget [DOT] fedora [AT] gmail [DOT] com> - 0.7.8-1
- New upstream version

* Tue Mar 17 2009 Orcan Ogetbil <oget [DOT] fedora [AT] gmail [DOT] com> - 0.7.7-2
- Remove BuildRequires:  dbus-python
- Fix the year of the previous changelog entry
- Add "Public Domain" to the license tag
- Add AudioVideo category to the .desktop file
- Add disttag

* Sun Mar 15 2009 Orcan Ogetbil <oget [DOT] fedora [AT] gmail [DOT] com> - 0.7.7-1
- Initial build
